@@ -1,20 +1,20 @@
 /*
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; You may only use version 2 of the License,
- you have no option to use any other version.
+        This program is free software; you can redistribute it and/or modify
+        it under the terms of the GNU General Public License as published by
+        the Free Software Foundation; either version 2, or (at your option)
+        any later version.
  
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
+        This program is distributed in the hope that it will be useful,
+        but WITHOUT ANY WARRANTY; without even the implied warranty of
+        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+        GNU General Public License for more details.
  
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+        You should have received a copy of the GNU General Public License
+        along with this program; if not, write to the Free Software
+        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
-        xfce4 mcs plugin   - (c) 2002 Olivier Fourdan
  
+        shortcut editor - Copyright (C) 2004 Jean-Francois Wauthy
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,7 +30,6 @@
 
 #include "xfwm4_plugin.h"
 #include "xfwm4_shortcuteditor.h"
-#include "keys-icon.h"
 
 void
 loadtheme_in_treeview (gchar * theme_file, gpointer data)
@@ -934,7 +933,7 @@ cb_activate_treeview3 (GtkWidget * treeview, GtkTreePath * path, GtkTreeViewColu
     gtk_container_set_border_width (GTK_CONTAINER (hbox),10);
     gtk_widget_show (hbox);
 
-    icon = xfce_inline_icon_at_size (keys_icon_data, 48, 48);
+    icon = xfce_themed_icon_load ("xfce4-keys", 48);
     if (icon)
     {
         image = gtk_image_new_from_pixbuf (icon);
@@ -1113,7 +1112,7 @@ cb_activate_treeview4 (GtkWidget * treeview, GtkTreePath * path, GtkTreeViewColu
 	gtk_container_set_border_width (GTK_CONTAINER (hbox),10);
 	gtk_widget_show (hbox);
 
-	icon = xfce_inline_icon_at_size (keys_icon_data, 48, 48);
+	icon = xfce_themed_icon_load ("xfce4-keys.png", 48);
 	if (icon)
 	{
 	    image = gtk_image_new_from_pixbuf (icon);
