@@ -994,7 +994,7 @@ handleUnmapNotify (DisplayInfo *display_info, XUnmapEvent * ev)
     if (c)
     {
         TRACE ("UnmapNotify for \"%s\" (0x%lx)", c->name, c->window);
-        TRACE ("ignore_unmaps for \"%s\" is %i", c->name, c->ignore_unmap);
+        TRACE ("ignore_unmap for \"%s\" is %i", c->name, c->ignore_unmap);
 
         if (FLAG_TEST (c->flags, CLIENT_FLAG_MAP_PENDING))
         {
@@ -1018,8 +1018,7 @@ handleUnmapNotify (DisplayInfo *display_info, XUnmapEvent * ev)
          * Therefore, bypass the ignore_unmap counter and
          * unframe the client.
          */
-        if (!FLAG_TEST (c->flags, CLIENT_FLAG_VISIBLE) && 
-            (ev->event == screen_info->xroot) && (ev->send_event))
+        if ((ev->event == screen_info->xroot) && (ev->send_event))
         {
             TRACE ("ICCCM UnmapNotify for \"%s\"", c->name);
             clientUnframe (c, FALSE);
@@ -1028,7 +1027,7 @@ handleUnmapNotify (DisplayInfo *display_info, XUnmapEvent * ev)
         if (c->ignore_unmap)
         {
             c->ignore_unmap--;
-            TRACE ("ignore_unmaps for \"%s\" is now %i", 
+            TRACE ("ignore_unmap for \"%s\" is now %i", 
                  c->name, c->ignore_unmap);
         }
         else
@@ -1410,6 +1409,7 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
 {
     ScreenInfo *screen_info = NULL;
     Client *c = NULL;
+    Window w = None;
     char *names;
     int length;
 
@@ -1425,7 +1425,7 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
         }
         else if ((ev->atom == XA_WM_NAME) || (ev->atom == net_wm_name))
         {
-            TRACE ("client \"%s\" (0x%lx) has received a XA_WM_NAME notify" c->name, c->window);
+            TRACE ("client \"%s\" (0x%lx) has received a XA_WM_NAME notify", c->name, c->window);
             if (c->name)
             {
                 free (c->name);
@@ -1456,6 +1456,16 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
             TRACE ("client \"%s\" (0x%lx) has received a wm_protocols notify", c->name, c->window);
             clientGetWMProtocols (c);
         }
+        else if (ev->atom == wm_transient_for)
+        {
+            TRACE ("client \"%s\" (0x%lx) has received a wm_transient_for notify", c->name, c->window);
+            getTransientFor (display_info->dpy, c->screen_info->screen, c->window, &w);
+            if (clientCheckTransientWindow (c, w))
+            {
+                c->transient_for = w;
+                clientRaise (c);
+            }
+        }
         else if (ev->atom == win_hints)
         {
             TRACE ("client \"%s\" (0x%lx) has received a win_hints notify", c->name, c->window);
