@@ -57,6 +57,7 @@ Atom wm_hints;
 Atom wm_protocols;
 Atom wm_state;
 Atom wm_takefocus;
+Atom wm_transient_for;
 Atom wm_window_role;
 
 /* freedesktop.org protocol */
@@ -108,7 +109,7 @@ Atom net_wm_window_type_dialog;
 Atom net_wm_window_type_dock;
 Atom net_wm_window_type_menu;
 Atom net_wm_window_type_normal;
-Atom net_wm_window_type_splashscreen;
+Atom net_wm_window_type_splash;
 Atom net_wm_window_type_toolbar;
 Atom net_wm_window_type_utility;
 Atom net_wm_user_time;
@@ -152,6 +153,7 @@ initICCCMHints (Display * dpy)
     wm_state = XInternAtom (dpy, "WM_STATE", FALSE);
     wm_takefocus = XInternAtom (dpy, "WM_TAKE_FOCUS", FALSE);
     wm_window_role = XInternAtom (dpy, "WM_WINDOW_ROLE", FALSE);
+    wm_transient_for = XInternAtom (dpy, "WM_TRANSIENT_FOR", FALSE);
 }
 
 unsigned long
@@ -485,8 +487,8 @@ initNetHints (Display * dpy)
         XInternAtom (dpy, "_NET_WM_WINDOW_TYPE_MENU", FALSE);
     net_wm_window_type_normal =
         XInternAtom (dpy, "_NET_WM_WINDOW_TYPE_NORMAL", FALSE);
-    net_wm_window_type_splashscreen =
-        XInternAtom (dpy, "_NET_WM_WINDOW_TYPE_SPLASHSCREEN", FALSE);
+    net_wm_window_type_splash =
+        XInternAtom (dpy, "_NET_WM_WINDOW_TYPE_SPLASH", FALSE);
     net_wm_window_type_toolbar =
         XInternAtom (dpy, "_NET_WM_WINDOW_TYPE_TOOLBAR", FALSE);
     net_wm_window_type_utility =
@@ -550,7 +552,7 @@ setNetSupportedHint (Display * dpy, int screen, Window check_win)
     atoms[i++] = net_wm_window_type_dock;
     atoms[i++] = net_wm_window_type_menu;
     atoms[i++] = net_wm_window_type_normal;
-    atoms[i++] = net_wm_window_type_splashscreen;
+    atoms[i++] = net_wm_window_type_splash;
     atoms[i++] = net_wm_window_type_toolbar;
     atoms[i++] = net_wm_window_type_utility;
     atoms[i++] = net_wm_user_time;
