@@ -137,6 +137,7 @@ extern Atom wm_delete_window;
 extern Atom wm_protocols;
 extern Atom wm_state;
 extern Atom wm_takefocus;
+extern Atom wm_transient_for;
 extern Atom wm_window_role;
 
 /* freedesktop.org protocol */
@@ -189,7 +190,7 @@ extern Atom net_wm_window_type_dialog;
 extern Atom net_wm_window_type_dock;
 extern Atom net_wm_window_type_menu;
 extern Atom net_wm_window_type_normal;
-extern Atom net_wm_window_type_splashscreen;
+extern Atom net_wm_window_type_splash;
 extern Atom net_wm_window_type_toolbar;
 extern Atom net_wm_window_type_utility;
 extern Atom net_wm_user_time;
